@@ -6,7 +6,7 @@ use crate::{DebugPls, Formatter};
 /// # Examples
 ///
 /// ```rust
-/// use dbg_pls::{debug, DebugPls, Formatter};
+/// use dbg_pls::{pretty, DebugPls, Formatter};
 ///
 /// struct Foo(i32, String);
 ///
@@ -20,7 +20,7 @@ use crate::{DebugPls, Formatter};
 /// }
 ///
 /// let value = Foo(10, "Hello".to_string());
-/// assert_eq!(format!("{}", debug(&value)), "(10, \"Hello\")");
+/// assert_eq!(format!("{}", pretty(&value)), "(10, \"Hello\")");
 /// ```
 pub struct DebugTuple<'a> {
     formatter: Formatter<'a>,
@@ -40,6 +40,7 @@ impl<'a> DebugTuple<'a> {
     }
 
     /// Adds the field to the tuple output.
+    #[must_use]
     pub fn field(mut self, value: &dyn DebugPls) -> Self {
         self.expr.elems.push(Formatter::process(value));
         self
